@@ -43,6 +43,7 @@ module Graphics.Rendering.Chart(
     module Graphics.Rendering.Chart.Axis,
     module Graphics.Rendering.Chart.Plot,
     module Graphics.Rendering.Chart.Legend,
+    module Graphics.Rendering.Chart.Backend.Types
 
 ) where
 
@@ -53,3 +54,4 @@ import Graphics.Rendering.Chart.Layout
 import Graphics.Rendering.Chart.Axis
 import Graphics.Rendering.Chart.Plot
 import Graphics.Rendering.Chart.Legend
+import Graphics.Rendering.Chart.Backend.Types
