@@ -6,13 +6,12 @@
 --
 -- Calculate and render unit indexed axes
 
-{-# LANGUAGE GeneralizedNewtypeDeriving #-}
-{-# OPTIONS_GHC -XTemplateHaskell #-}
-
 module Graphics.Rendering.Chart.Axis.Unit(
     unitAxis,
 ) where
 
+import Data.Default.Class
+
 import Graphics.Rendering.Chart.Axis.Types
 
 instance PlotValue () where
@@ -22,9 +21,13 @@ instance PlotValue () where
 
 unitAxis :: AxisData ()
 unitAxis = AxisData {
-    axis_viewport_ = \(x0,x1) _ -> (x0+x1)/2,
-    axis_tropweiv_ = \_       _ -> (),
-    axis_ticks_    = [((), 0)],
-    axis_labels_   = [[((), "")]],
-    axis_grid_     = []
+    _axis_visibility = def 
+                     { _axis_show_ticks  = False
+                     , _axis_show_labels = False 
+                     },
+    _axis_viewport = \(x0,x1) _ -> (x0+x1)/2,
+    _axis_tropweiv = \_       _ -> (),
+    _axis_ticks    = [((), 0)],
+    _axis_labels   = [[((), "")]],
+    _axis_grid     = []
 }
